#' mrbayes: Bayesian implementation of the IVW and MR-Egger models for two-sample Mendelian randomization analyses
#'
#' Bayesian implementation of the IVW and MR-Egger models and their radial and
#' multivariate versions for two-sample Mendelian randomization analyses.
#'
#' @name mrbayes-package
#' @aliases mrbayes
#' @useDynLib mrbayes, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @importFrom rstan sampling
#' @importFrom rstantools rstan_config
#' @importFrom RcppParallel RcppParallelLibs
#'
#' @references
#' Stan Development Team (2019). RStan: the R interface to Stan. R package version 2.19.2. \url{https://mc-stan.org}
"_PACKAGE"
